@@ -47,3 +47,58 @@ sub delete {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+HTTP::Session::Store::DBM - DBM session store
+
+=head1 SYNOPSIS
+
+    HTTP::Session->new(
+        store => HTTP::Session::Store::DBM->new(
+            file      => '/path/to/file',
+            dbm_class => 'GDBM_File',
+        ),
+        state => ...,
+        request => ...,
+    );
+
+=head1 DESCRIPTION
+
+DBM session store
+
+=head1 CONFIGURATION
+
+=over 4
+
+=item dbm_class
+
+    default: SDBM_File
+
+=item file
+
+path to dbm
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+=item select
+
+=item update
+
+=item delete
+
+=item insert
+
+for internal use only
+
+=back
+
+=head1 SEE ALSO
+
+L<HTTP::Session>
+
